@@ -13,7 +13,7 @@ register_admin_task({
 
 ajax '/ajax/control/admin/jobqueue/del' => sub {
     send_error('Forbidden', 403) unless var('user')->admin;
-    send_error('Missing job', 400) unless length param('job');
+    send_error('Missing job', 400) unless param('job');
 
     schema('netdisco')->txn_do(sub {
       my $device = schema('netdisco')->resultset('Admin')
@@ -21,12 +21,23 @@ ajax '/ajax/control/admin/jobqueue/del' => sub {
     });
 };
 
+ajax '/ajax/control/admin/jobqueue/delall' => sub {
+    send_error('Forbidden', 403) unless var('user')->admin;
+
+    schema('netdisco')->txn_do(sub {
+      my $device = schema('netdisco')->resultset('Admin')->delete;
+    });
+};
+
 ajax '/ajax/content/admin/jobqueue' => sub {
     send_error('Forbidden', 403) unless var('user')->admin;
 
     my $set = schema('netdisco')->resultset('Admin')
       ->with_times
-      ->search({}, {order_by => { -desc => [qw/entered device action/] }});
+      ->search({}, {
+        order_by => { -desc => [qw/entered device action/] },
+        rows => 200,
+      });
 
     content_type('text/html');
     template 'ajax/admintask/jobqueue.tt', {
